<?php

// autoload_psr4.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Twilio\\' => array($baseDir . '/src/Twilio', $vendorDir . '/twilio/sdk/src/Twilio'),
);
