<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit983a014ab5a4fb12b26abf6648390af3
{
    public static $prefixLengthsPsr4 = array (
        'T' => 
        array (
            'Twilio\\' => 7,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'Twilio\\' => 
        array (
            0 => __DIR__ . '/../..' . '/src/Twilio',
            1 => __DIR__ . '/..' . '/twilio/sdk/src/Twilio',
        ),
    );

    public static $classMap = array (
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInit983a014ab5a4fb12b26abf6648390af3::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInit983a014ab5a4fb12b26abf6648390af3::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInit983a014ab5a4fb12b26abf6648390af3::$classMap;

        }, null, ClassLoader::class);
    }
}
