<?php return array(
    'root' => array(
        'name' => 'twilio/sdk-sms-relentless',
        'pretty_version' => '1.0.0+no-version-set',
        'version' => '1.0.0.0',
        'reference' => NULL,
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => true,
    ),
    'versions' => array(
        'twilio/sdk' => array(
            'pretty_version' => '6.40.1',
            'version' => '6.40.1.0',
            'reference' => '94aa139df0bea5aadddb59353ed0ea220fa65c78',
            'type' => 'library',
            'install_path' => __DIR__ . '/../twilio/sdk',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'twilio/sdk-sms-relentless' => array(
            'pretty_version' => '1.0.0+no-version-set',
            'version' => '1.0.0.0',
            'reference' => NULL,
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
